@@ -23,7 +23,7 @@ from .cursor import Cursor
 from .exceptions import ProgrammingError, ConnectionError
 from .http import Client
 from .blob import BlobContainer
-from distutils.version import StrictVersion
+from ._pep440 import Version
 
 
 class Connection(object):
@@ -46,6 +46,8 @@ class Connection(object):
                  socket_tcp_keepidle=None,
                  socket_tcp_keepintvl=None,
                  socket_tcp_keepcnt=None,
+                 converter=None,
+                 time_zone=None,
                  ):
         """
         :param servers:
@@ -99,7 +101,32 @@ class Connection(object):
             Set the ``TCP_KEEPCNT`` socket option, which overrides
             ``net.ipv4.tcp_keepalive_probes`` kernel setting if ``socket_keepalive``
             is ``True``.
+        :param converter:
+            (optional, defaults to ``None``)
+            A `Converter` object to propagate to newly created `Cursor` objects.
+        :param time_zone:
+            (optional, defaults to ``None``)
+            A time zone specifier used for returning `TIMESTAMP` types as
+            timezone-aware native Python `datetime` objects.
+
+            Different data types are supported. Available options are:
+
+            - ``datetime.timezone.utc``
+            - ``datetime.timezone(datetime.timedelta(hours=7), name="MST")``
+            - ``pytz.timezone("Australia/Sydney")``
+            - ``zoneinfo.ZoneInfo("Australia/Sydney")``
+            - ``+0530`` (UTC offset in string format)
+
+            When `time_zone` is `None`, the returned `datetime` objects are
+            "naive", without any `tzinfo`, converted using ``datetime.utcfromtimestamp(...)``.
+
+            When `time_zone` is given, the returned `datetime` objects are "aware",
+            with `tzinfo` set, converted using ``datetime.fromtimestamp(..., tz=...)``.
         """
+
+        self._converter = converter
+        self.time_zone = time_zone
+
         if client:
             self.client = client
         else:
@@ -123,12 +150,18 @@ class Connection(object):
         self.lowest_server_version = self._lowest_server_version()
         self._closed = False
 
-    def cursor(self):
+    def cursor(self, **kwargs) -> Cursor:
         """
         Return a new Cursor Object using the connection.
         """
+        converter = kwargs.pop("converter", self._converter)
+        time_zone = kwargs.pop("time_zone", self.time_zone)
         if not self._closed:
-            return Cursor(self)
+            return Cursor(
+                connection=self,
+                converter=converter,
+                time_zone=time_zone,
+            )
         else:
             raise ProgrammingError("Connection closed")
 
@@ -159,12 +192,12 @@ class Connection(object):
         for server in self.client.active_servers:
             try:
                 _, _, version = self.client.server_infos(server)
-                version = StrictVersion(version)
+                version = Version(version)
             except (ValueError, ConnectionError):
                 continue
             if not lowest or version < lowest:
                 lowest = version
-        return lowest or StrictVersion('0.0.0')
+        return lowest or Version('0.0.0')
 
     def __repr__(self):
         return '<Connection {0}>'.format(repr(self.client))
