@@ -20,8 +20,9 @@
 # software solely pursuant to the terms of the relevant commercial agreement.
 
 import sqlalchemy as sa
-from distutils.version import StrictVersion as V
+from crate.client._pep440 import Version
 
-SA_VERSION = V(sa.__version__)
+SA_VERSION = Version(sa.__version__)
 
-SA_1_4 = V('1.4.0b1')
+SA_1_4 = Version('1.4.0b1')
+SA_2_0 = Version('2.0.0')
